<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Stream\Crypto;

// Import framework stuff
use Org\Mxchange\CoreFramework\Crypto\RandomNumber\RandomNumberGenerator;
use Org\Mxchange\CoreFramework\Stream\BaseStream;

/**
 * A general crypto stream class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2020 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
abstract class BaseCryptoStream extends BaseStream {
	/**
	 * Instance of a RNG
	 */
	private $rngInstance = NULL;

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct (string $className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Setter for RNG instance
	 *
	 * @param	$rngInstance	An instance of a random number generator (RNG)
	 * @return	void
	 */
	protected final function setRngInstance (RandomNumberGenerator $rngInstance) {
		$this->rngInstance = $rngInstance;
	}

	/**
	 * Getter for RNG instance
	 *
	 * @return	$rngInstance	An instance of a random number generator (RNG)
	 */
	protected final function getRngInstance () {
		return $this->rngInstance;
	}

}
